@@ -13,13 +13,17 @@ class MultiplexMessage:
         self._payload = payload
 
     @property
-    def identity(self):
+    def identity(self) -> str:
         return self._identity
 
     @property
-    def type(self):
+    def type(self) -> InterstateWireMessageType:
         return self._type
 
     @property
     def payload(self):
-        return self._payload
\ No newline at end of file
+        return self._payload
+
+    def __repr__(self) -> str:
+        return "MultiplexMessage(identity={}, type={})".format(self._identity, self._type)
+
