@@ -3,10 +3,14 @@ from typing import Any
 from rx import Observable
 from rx.subject import Subject
 
+from interstate_py.log_factory import LogFactory
 from interstate_py.stream_connection import StreamConnection
 
 
 class RxStreamConnection(StreamConnection):
+
+    _log = LogFactory.get_logger(__name__)
+
     """
     Concrete StreamConnection using RxPY 1.x under the hood.
     """
@@ -23,11 +27,9 @@ class RxStreamConnection(StreamConnection):
         return self._identity
 
     def inbound_stream(self) -> Any:
-        # TODO: abstract
         return self._inbound_subject
 
     def outbound_stream(self) -> Any:
-        # TODO: abstract
         return self._outbound_observable
 
     def closed_count(self) -> int:
@@ -35,6 +37,7 @@ class RxStreamConnection(StreamConnection):
 
     def close_inbound(self):
         try:
+            self._log.debug("Closing inbound connection for %s", self._identity)
             self._inbound_subject.check_disposed()  # throws
             self._inbound_subject.dispose()
             self._close_count = self._close_count + 1
@@ -43,4 +46,5 @@ class RxStreamConnection(StreamConnection):
 
     def close_outbound(self):
         if self._close_count < 2:
+            self._log.debug("Closing outbound connection for %s", self._identity)
             self._close_count = self._close_count + 1
