@@ -58,10 +58,11 @@ class StreamDemultiplexer(AIOWorkerTask):
 
         if message.type == InterstateWireMessageType.NEXT:
             self._log.debug("[IN][NEXT] - {}".format(message))
+            deserialized_payload = await self._deserialize(message)
             asyncio.get_event_loop().run_in_executor(self._pool,  # TODO: configurable
                                                      _dispatch,
                                                      connection,
-                                                     self._deserialize(message))
+                                                     deserialized_payload)
 
         elif message.type == InterstateWireMessageType.ERROR:
             self._log.warn("[IN][ERROR] - {}".format(message))
